#!/usr/bin/env bash
#
# Run the Organic compare script against a series of documents sourced from exterior places.
set -euo pipefail
IFS=$'\n\t'
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

function log {
    (>&2 echo "${@}")
}

function die {
    local status_code="$1"
    shift
    (>&2 echo "${@}")
    exit "$status_code"
}

function main {
    cargo build --no-default-features --features compare --profile release-lto
    if [ "${CARGO_TARGET_DIR:-}" = "" ]; then
        CARGO_TARGET_DIR=$(realpath target/)
    fi
    PARSE="${CARGO_TARGET_DIR}/release-lto/parse"

    run_compare "org-mode/org-guide.org" "/foreign_documents/org-mode/org-guide.org"
    run_compare "org-mode/org-manual.org" "/foreign_documents/org-mode/org-manual.org"
}

function run_compare {
    local name="$1"
    local target_document="$2"
    set +e
    $PARSE "$target_document" &> /dev/null
    local status=$?
    set -e
    if [ "$status" -eq 0 ]; then
        echo "$(green_text "GOOD")  $name"
    else
        echo "$(red_text "FAIL")  $name"
        return 1
    fi
}

function green_text {
    (IFS=' '; printf '\x1b[38;2;0;255;0m%s\x1b[0m' "${*}")
}

function red_text {
    (IFS=' '; printf '\x1b[38;2;255;0;0m%s\x1b[0m' "${*}")
}

function yellow_text {
    (IFS=' '; printf '\x1b[38;2;255;255;0m%s\x1b[0m' "${*}")
}

main "${@}"
